@@ -118,6 +118,28 @@ class DummyGrf():
    def TxExt( self, text, x, y, just, upx, upy ):
       return (x-0.1,x+0.1,x+0.1,x-0.1,y-0.1,y-0.1,y+0.1,y+0.1)
 
+   def IntToCol( self, col ):
+      if col == 0:
+         return "red"
+      elif col == 1:
+         return "blue"
+      elif col == 2:
+         return "green"
+      else:
+         return None
+
+   def ColToInt( self, col ):
+      if col == "red":
+         return 0;
+      elif col == "blue":
+         return 1
+      elif col == "green":
+         return 2
+      else:
+         try:
+            return int(col)
+         except ValueError:
+            return None
 
 #  Tester
 class TestAst(unittest.TestCase):
@@ -583,6 +605,7 @@ class TestAst(unittest.TestCase):
       refpos = specframe.getrefpos(sky)
       self.assertAlmostEqual( refpos[0], 0, 5 )
       self.assertAlmostEqual( refpos[1], 1 )
+      self.assertEqual( specframe.InternalUnit_1, specframe.Unit_1, )
 
    def test_DSBSpecFrame(self):
       dsbspecframe = starlink.Ast.DSBSpecFrame( "IF=4.0,AlignSideBand=1")
@@ -598,6 +621,8 @@ class TestAst(unittest.TestCase):
       self.assertIsInstance( skyframe, starlink.Ast.SkyFrame )
       mapping = skyframe.skyoffsetmap()
       self.assertIsInstance( mapping, starlink.Ast.Mapping )
+      self.assertEqual( skyframe.InternalUnit_1, "rad" )
+      self.assertEqual( skyframe.InternalUnit_2, "rad" )
 
    def test_TimeFrame(self):
       tframe = starlink.Ast.TimeFrame( "TimeScale=TAI" )
@@ -1035,9 +1060,18 @@ class TestAst(unittest.TestCase):
       plot.Tol = 0.5
       self.assertEqual( plot.Tol, 0.5 )
 
-      self.assertEqual( plot.Colour_Border, 1 )
+      plot.Colour_Title = "red"
+      self.assertEqual( plot.Colour_Title, "red" )
+      plot.Colour_Title = 1
+      self.assertEqual( plot.Colour_Title, "blue" )
+      plot.Colour_Title = 5
+      self.assertEqual( plot.Colour_Title, 5 )
+
+      self.assertEqual( plot.Colour_Border, "blue" )
+      plot.Colour_Border = 5
+      self.assertEqual( plot.Colour_Border, 5 )
       plot.Colour_Border = 2
-      self.assertEqual( plot.Colour_Border, 2 )
+      self.assertEqual( plot.Colour_Border, "green" )
 
       plot.border()
 
@@ -1133,6 +1167,14 @@ class TestAst(unittest.TestCase):
       self.assertEqual( mygrf.textj, ['CC'] )
       self.assertEqual( mygrf.ntext, 1 )
 
+      mygrf.Reset()
+      circle = starlink.Ast.Circle( plot, 0, [0.5,0.5],[0.5,0.7] )
+      plot.regionoutline( circle )
+      self.assertAlmostEqual(max( mygrf.linex), 0.7 )
+      self.assertAlmostEqual(min( mygrf.linex), 0.3 )
+      self.assertAlmostEqual(max( mygrf.liney), 0.7 )
+      self.assertAlmostEqual(min( mygrf.liney), 0.3 )
+
    def test_MatrixMap(self):
 
       with self.assertRaises(ValueError):
@@ -1265,6 +1307,8 @@ class TestAst(unittest.TestCase):
       self.assertIsInstance( polygon, starlink.Ast.Region )
       self.assertIsInstance( polygon, starlink.Ast.Frame )
       self.assertIsInstance( polygon.getregionframe(), starlink.Ast.Frame )
+      self.assertTrue( numpy.array_equal(polygon.getregionpoints(),
+                                         [[0,1,0],[0,1,2]] ) )
       overlap = polygon.overlap( polygon )
       self.assertEqual( overlap, 5 )
       testpolygon = starlink.Ast.Polygon( starlink.Ast.Frame(2),
